@@ -9,11 +9,11 @@ class dstat_plugin(dstat):
 
     def check(self): 
         if not os.access('/usr/bin/mysql', os.X_OK):
-            raise Exception, 'Needs MySQL binary'
+            raise Exception('Needs MySQL binary')
         try:
             self.stdin, self.stdout, self.stderr = dpopen('/usr/bin/mysql -n %s' % mysql_options)
         except IOError:
-            raise Exception, 'Cannot interface with MySQL binary'
+            raise Exception('Cannot interface with MySQL binary')
 
     def extract(self):
         try:
@@ -30,12 +30,12 @@ class dstat_plugin(dstat):
             if step == op.delay:
                 self.set1.update(self.set2)
 
-        except IOError, e:
-            if op.debug > 1: print '%s: lost pipe to mysql, %s' % (self.filename, e)
+        except IOError as e:
+            if op.debug > 1: print('%s: lost pipe to mysql, %s' % (self.filename, e))
             for name in self.vars: self.val[name] = -1
 
-        except Exception, e:
-            if op.debug > 1: print 'dstat_innodb_buffer: exception', e
+        except Exception as e:
+            if op.debug > 1: print('dstat_innodb_buffer: exception', e)
             for name in self.vars: self.val[name] = -1
 
 # vim:ts=4:sw=4:et
