@@ -20,7 +20,7 @@ class dstat_plugin(dstat):
 
             self.gl = vmguestlib.VMGuestLib()
         except:
-            raise Exception, 'Needs python-vmguestlib module'
+            raise Exception('Needs python-vmguestlib module')
 
     def extract(self):
         self.gl.UpdateInfo()
@@ -30,4 +30,4 @@ class dstat_plugin(dstat):
         self.val['swapped'] = self.gl.GetMemSwappedMB() * 1024 ** 2
         self.val['used'] = self.gl.GetMemUsedMB() * 1024 ** 2
 
-# vim:ts=4:sw=4
\ No newline at end of file
+# vim:ts=4:sw=4
